@@ -20,6 +20,9 @@ urlpatterns = [
     path('print-name/<int:product_id>/', views.print_product_name,
          name='print-name'),
 
+    path('print-bar-code/<int:product_id>/', views.print_product_bar_code,
+         name='print-bar-code'),
+
     path('history/<int:product_id>/', views.get_product_history,
          name='history')
 
