@@ -23,12 +23,17 @@ def get_id_from_bar_code(request):
     return HttpResponse(product.id)
 
 
-@admin_render_view(template_name='products/print_name.html')
+@admin_render_view(template_name='invoice_products/print_name.html')
 def print_product_name(request, product_id):
     return {'product': get_object_or_404(Product, pk=product_id)}
 
 
-@admin_render_view(template_name='products/history.html')
+@admin_render_view(template_name='invoice_products/print_bar_code.html')
+def print_product_bar_code(request, product_id):
+    return {'product': get_object_or_404(Product, pk=product_id)}
+
+
+@admin_render_view(template_name='invoice_products/history.html')
 def get_product_history(request, product_id):
 
     product = get_object_or_404(Product, pk=product_id)
